@@ -6,22 +6,22 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.092 ();
+use IO::Compress::Base::Common  2.094 ();
 
-use IO::Uncompress::Adapter::Inflate  2.092 ();
+use IO::Uncompress::Adapter::Inflate  2.094 ();
 
 
-use IO::Uncompress::Base  2.092 ;
-use IO::Uncompress::Gunzip  2.092 ;
-use IO::Uncompress::Inflate  2.092 ;
-use IO::Uncompress::RawInflate  2.092 ;
-use IO::Uncompress::Unzip  2.092 ;
+use IO::Uncompress::Base  2.094 ;
+use IO::Uncompress::Gunzip  2.094 ;
+use IO::Uncompress::Inflate  2.094 ;
+use IO::Uncompress::RawInflate  2.094 ;
+use IO::Uncompress::Unzip  2.094 ;
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyInflateError);
 
-$VERSION = '2.092';
+$VERSION = '2.094';
 $AnyInflateError = '';
 
 @ISA = qw(IO::Uncompress::Base Exporter);
@@ -48,7 +48,7 @@ sub anyinflate
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common  2.092 qw(:Parse);
+    use IO::Compress::Base::Common  2.094 qw(:Parse);
     return ( 'rawinflate' => [Parse_boolean,  0] ) ;
 }
 
@@ -227,7 +227,7 @@ It can take one of the following forms:
 
 =item A filename
 
-If the <$input_filename_or_reference> parameter is a simple scalar, it is
+If the C<$input_filename_or_reference> parameter is a simple scalar, it is
 assumed to be a filename. This file will be opened for reading and the
 input data will be read from it.
 
@@ -999,7 +999,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2019 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2020 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
