@@ -4,16 +4,16 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.092 ();
+use IO::Compress::Base::Common 2.094 ();
 
-use IO::Uncompress::Base 2.092 ;
+use IO::Uncompress::Base 2.094 ;
 
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyUncompressError);
 
-$VERSION = '2.092';
+$VERSION = '2.094';
 $AnyUncompressError = '';
 
 @ISA = qw(IO::Uncompress::Base Exporter);
@@ -33,26 +33,26 @@ BEGIN
    # Don't trigger any __DIE__ Hooks.
    local $SIG{__DIE__};
 
-   eval ' use IO::Uncompress::Adapter::Inflate 2.092 ;';
-   eval ' use IO::Uncompress::Adapter::Bunzip2 2.092 ;';
-   eval ' use IO::Uncompress::Adapter::LZO 2.092 ;';
-   eval ' use IO::Uncompress::Adapter::Lzf 2.092 ;';
-   eval ' use IO::Uncompress::Adapter::UnLzma 2.092 ;';
-   eval ' use IO::Uncompress::Adapter::UnXz 2.092 ;';
+   eval ' use IO::Uncompress::Adapter::Inflate 2.094 ;';
+   eval ' use IO::Uncompress::Adapter::Bunzip2 2.094 ;';
+   eval ' use IO::Uncompress::Adapter::LZO 2.094 ;';
+   eval ' use IO::Uncompress::Adapter::Lzf 2.094 ;';
+   eval ' use IO::Uncompress::Adapter::UnLzma 2.094 ;';
+   eval ' use IO::Uncompress::Adapter::UnXz 2.094 ;';
    eval ' use IO::Uncompress::Adapter::UnZstd 2.083 ;';
-   eval ' use IO::Uncompress::Adapter::UnLzip 2.092 ;';
+   eval ' use IO::Uncompress::Adapter::UnLzip 2.094 ;';
 
-   eval ' use IO::Uncompress::Bunzip2 2.092 ;';
-   eval ' use IO::Uncompress::UnLzop 2.092 ;';
-   eval ' use IO::Uncompress::Gunzip 2.092 ;';
-   eval ' use IO::Uncompress::Inflate 2.092 ;';
-   eval ' use IO::Uncompress::RawInflate 2.092 ;';
-   eval ' use IO::Uncompress::Unzip 2.092 ;';
-   eval ' use IO::Uncompress::UnLzf 2.092 ;';
-   eval ' use IO::Uncompress::UnLzma 2.092 ;';
-   eval ' use IO::Uncompress::UnXz 2.092 ;';
-   eval ' use IO::Uncompress::UnZstd 2.092 ;';
-   eval ' use IO::Uncompress::UnLzip 2.092 ;';
+   eval ' use IO::Uncompress::Bunzip2 2.094 ;';
+   eval ' use IO::Uncompress::UnLzop 2.094 ;';
+   eval ' use IO::Uncompress::Gunzip 2.094 ;';
+   eval ' use IO::Uncompress::Inflate 2.094 ;';
+   eval ' use IO::Uncompress::RawInflate 2.094 ;';
+   eval ' use IO::Uncompress::Unzip 2.094 ;';
+   eval ' use IO::Uncompress::UnLzf 2.094 ;';
+   eval ' use IO::Uncompress::UnLzma 2.094 ;';
+   eval ' use IO::Uncompress::UnXz 2.094 ;';
+   eval ' use IO::Uncompress::UnZstd 2.094 ;';
+   eval ' use IO::Uncompress::UnLzip 2.094 ;';
 
 }
 
@@ -381,7 +381,7 @@ It can take one of the following forms:
 
 =item A filename
 
-If the <$input_filename_or_reference> parameter is a simple scalar, it is
+If the C<$input_filename_or_reference> parameter is a simple scalar, it is
 assumed to be a filename. This file will be opened for reading and the
 input data will be read from it.
 
@@ -1075,7 +1075,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2019 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2020 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
