@@ -9,12 +9,12 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Uncompress::RawInflate 2.092 ;
+use IO::Uncompress::RawInflate 2.094 ;
 
-use Compress::Raw::Zlib 2.092 () ;
-use IO::Compress::Base::Common 2.092 qw(:Status );
-use IO::Compress::Gzip::Constants 2.092 ;
-use IO::Compress::Zlib::Extra 2.092 ;
+use Compress::Raw::Zlib 2.094 () ;
+use IO::Compress::Base::Common 2.094 qw(:Status );
+use IO::Compress::Gzip::Constants 2.094 ;
+use IO::Compress::Zlib::Extra 2.094 ;
 
 require Exporter ;
 
@@ -28,7 +28,7 @@ Exporter::export_ok_tags('all');
 
 $GunzipError = '';
 
-$VERSION = '2.092';
+$VERSION = '2.094';
 
 sub new
 {
@@ -362,7 +362,7 @@ It can take one of the following forms:
 
 =item A filename
 
-If the <$input_filename_or_reference> parameter is a simple scalar, it is
+If the C<$input_filename_or_reference> parameter is a simple scalar, it is
 assumed to be a filename. This file will be opened for reading and the
 input data will be read from it.
 
@@ -1122,7 +1122,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2019 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2020 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
